==> zio-aws-comprehend_2.13-5.17.225.1-sources.jar: zio/aws/comprehend/model/BatchDetectEntitiesItemResult.scala <==
package zio.aws.comprehend.model
import zio.aws.comprehend.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class BatchDetectEntitiesItemResult(
    index: Optional[Integer] = Optional.Absent,
    entities: Optional[Iterable[zio.aws.comprehend.model.Entity]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.comprehend.model.BatchDetectEntitiesItemResult = {
    import BatchDetectEntitiesItemResult.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.comprehend.model.BatchDetectEntitiesItemResult
      .builder()
      .optionallyWith(index.map(value => value: java.lang.Integer))(_.index)
      .optionallyWith(
        entities.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.entities)
      .build()
  }
  def asReadOnly
      : zio.aws.comprehend.model.BatchDetectEntitiesItemResult.ReadOnly =
    zio.aws.comprehend.model.BatchDetectEntitiesItemResult.wrap(buildAwsValue())
}
object BatchDetectEntitiesItemResult {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.comprehend.model.BatchDetectEntitiesItemResult
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.comprehend.model.BatchDetectEntitiesItemResult =
      zio.aws.comprehend.model.BatchDetectEntitiesItemResult(
        index.map(value => value),
        entities.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def index: Optional[Integer]
    def entities: Optional[List[zio.aws.comprehend.model.Entity.ReadOnly]]
    def getIndex: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("index", index)
    def getEntities
        : ZIO[Any, AwsError, List[zio.aws.comprehend.model.Entity.ReadOnly]] =
      AwsError.unwrapOptionField("entities", entities)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.comprehend.model.BatchDetectEntitiesItemResult
  ) extends zio.aws.comprehend.model.BatchDetectEntitiesItemResult.ReadOnly {
    override val index: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.index())
      .map(value => value: Integer)
    override val entities
        : Optional[List[zio.aws.comprehend.model.Entity.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.entities())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.comprehend.model.Entity.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.comprehend.model.BatchDetectEntitiesItemResult
  ): zio.aws.comprehend.model.BatchDetectEntitiesItemResult.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-comprehend_3-5.17.103.1-sources.jar: zio/aws/comprehend/model/BatchDetectEntitiesItemResult.scala <==
package zio.aws.comprehend.model
import zio.aws.comprehend.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class BatchDetectEntitiesItemResult(
    index: Option[Integer] = None,
    entities: Option[Iterable[zio.aws.comprehend.model.Entity]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.comprehend.model.BatchDetectEntitiesItemResult = {
    import BatchDetectEntitiesItemResult.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.comprehend.model.BatchDetectEntitiesItemResult
      .builder()
      .optionallyWith(
        index.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.index)
      .optionallyWith(
        entities.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.entities)
      .build()
  }
  def asReadOnly
      : zio.aws.comprehend.model.BatchDetectEntitiesItemResult.ReadOnly =
    zio.aws.comprehend.model.BatchDetectEntitiesItemResult.wrap(buildAwsValue())
}
object BatchDetectEntitiesItemResult {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.comprehend.model.BatchDetectEntitiesItemResult
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.comprehend.model.BatchDetectEntitiesItemResult =
      zio.aws.comprehend.model.BatchDetectEntitiesItemResult(
        index.map(value => value),
        entities.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def index: Option[Integer]
    def entities: Option[List[zio.aws.comprehend.model.Entity.ReadOnly]]
    def getIndex: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("index", index)
    def getEntities
        : ZIO[Any, AwsError, List[zio.aws.comprehend.model.Entity.ReadOnly]] =
      AwsError.unwrapOptionField("entities", entities)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.comprehend.model.BatchDetectEntitiesItemResult
  ) extends zio.aws.comprehend.model.BatchDetectEntitiesItemResult.ReadOnly {
    override val index: Option[Integer] = scala
      .Option(impl.index())
      .map(value => zio.aws.comprehend.model.primitives.Integer(value))
    override val entities
        : Option[List[zio.aws.comprehend.model.Entity.ReadOnly]] = scala
      .Option(impl.entities())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.comprehend.model.Entity.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.comprehend.model.BatchDetectEntitiesItemResult
  ): zio.aws.comprehend.model.BatchDetectEntitiesItemResult.ReadOnly =
    new Wrapper(impl)
}
